@@ -89,7 +89,7 @@ class gquilt_playground_tree(gquilt_gtk.dir_file_tree):
         files = self.get_selected_files()
         if len(files) == 0:
             return
-        pid = gquilt_utils.edit_files(files)
+        pid = gquilt_utils.peruse_files(files)
         self._clean_up_after_child(pid)
     def edit_selected_files(self):
         files = self.get_selected_files()
@@ -678,10 +678,10 @@ class gquilt(gtk.Window):
     def _refresh_top_patch(self, widget=None):
         self._refresh_patch()
         self._update_views()
-    def _pop_patch(self):
+    def _pop_patch(self, patch=None):
         while True:
             self._show_busy()
-            res, op, err = ifce.do_pop_patch(self.console)
+            res, op, err = ifce.do_pop_to_patch(self.console, patch)
             self._unshow_busy()
             if res != gquilt_tool.OK:
                 # if there's a problem make sure the views are up to date
@@ -712,7 +712,7 @@ class gquilt(gtk.Window):
             return True
     def _pop_to_patch(self, patch):
         while ifce.top_patch() != patch:
-            if not self._pop_patch():
+            if not self._pop_patch(patch):
                 break
         self._update_views()
     def _pop_top_patch(self, widget=None):
@@ -720,10 +720,10 @@ class gquilt(gtk.Window):
         self._update_views()
     def _pop_all_patches(self, widget):
         self._pop_to_patch("")
-    def _push_patch(self, widget=None):
+    def _push_patch(self, patch=None):
         while True:
             self._show_busy()
-            res, op, err = ifce.do_push_patch(self.console)
+            res, op, err = ifce.do_push_to_patch(self.console, patch)
             self._unshow_busy()
             if res != gquilt_tool.OK:
                 # if there's a problem make sure the views are up to date
@@ -750,7 +750,7 @@ class gquilt(gtk.Window):
             return True
     def _push_to_patch(self, patch):
         while ifce.top_patch() != patch:
-            if not self._push_patch():
+            if not self._push_patch(patch):
                 break
         self._update_views()
     def _push_next_patch(self, widget=None):
